function [ws,wa] = symasym(w)
% [ws,wa] = symasym(w)
%     Splits a column vector w into a symmetric part (ws)
%     and an asymmetric perturbation (wa)
%
%     Written by Rick Martin, 08/06/2002
%     Last updated 08/06/2002
%     Cornell University Blind Equalization Research Group

Lw = length(w);

meas = zeros(2*Lw-1,1);

% [1 1 2 1 1] sort of symmetry
for center = 1:Lw
   left = center-1;
   right = Lw-center;
   half = min(left,right);
   wmid = w(center-half:center+half);
   ws = zeros(Lw,1);
   ws(center-half:center+half) = (wmid+flipud(wmid))/2;
   wa = w-ws;
   meas(center) = norm(ws)/norm(wa);
end
% [1 2 2 1] sort of symmetry
for center = Lw+1:2*Lw-1
   left = center-Lw;
   right = Lw-left;
   half = min(left,right);
   wmid = w(left-half+1:left+half);
   ws = zeros(Lw,1);
   ws(left-half+1:left+half) = (wmid+flipud(wmid))/2;      
   wa = w-ws;
   meas(center) = norm(ws)/norm(wa);
end 

[dummy,center] = max(meas);
if center <= Lw
   left = center-1;
   right = Lw-center;
   half = min(left,right);
   wmid = w(center-half:center+half);
   ws = zeros(Lw,1);
   ws(center-half:center+half) = (wmid+flipud(wmid))/2;
   wa = w-ws;
else
   left = center-Lw;
   right = Lw-left;
   half = min(left,right);
   wmid = w(left-half+1:left+half);
   ws = zeros(Lw,1);
   ws(left-half+1:left+half) = (wmid+flipud(wmid))/2;
   wa = w-ws;
end
